==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileimporterexternal.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBibTeXFileImporterExternal_H
#define BIBTEXBibTeXFileImporterExternal_H

#include <bibtexfileimporter.h>
#include <settings.h>

class QWaitCondition;
class QProcess;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class BibTeXFileImporterExternal : public BibTeXFileImporter
    {
        Q_OBJECT
    public:
        BibTeXFileImporterExternal( Settings::Importer importer, Settings::FileFormat fileformat );
        ~BibTeXFileImporterExternal();

        BibTeXFile* load( QIODevice *iodevice );

    public slots:
        void cancel();

    private:
        QWaitCondition *wc;
        QProcess *process;
        QTextStream *writeTo;
        Settings::Importer m_importer;
        Settings::FileFormat m_fileformat;

        bool fetchInput( QIODevice *input, QBuffer &output );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();
        void slotWroteToStdin();
    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfileimporterexternal.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBibTeXFileImporterExternal_H
#define BIBTEXBibTeXFileImporterExternal_H

#include <bibtexfileimporter.h>
#include <settings.h>

class QWaitCondition;
class QProcess;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class BibTeXFileImporterExternal : public BibTeXFileImporter
    {
        Q_OBJECT
    public:
        BibTeXFileImporterExternal( KBibTeX::Settings::Importer importer, KBibTeX::Settings::FileFormat fileformat );
        ~BibTeXFileImporterExternal();

        BibTeXFile* load( QIODevice *iodevice );

    public slots:
        void cancel();

    private:
        QWaitCondition *wc;
        QProcess *process;
        QTextStream *writeTo;
        KBibTeX::Settings::Importer m_importer;
        KBibTeX::Settings::FileFormat m_fileformat;

        bool fetchInput( QIODevice *input, QBuffer &output );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();
        void slotWroteToStdin();
    };

}

#endif
